## Select Next Step

To make progress on answering the question, please answer the following questions, including necessary reasoning:

- What is the goal of the next step? (e.g., gather evidence, analyze data, etc.)
- Who should we be communicating with? (select from: {names})
- What instruction or question would you give this team member? (Phrase as if speaking directly to them, and include any specific information they may need)
